import React from "react";
import {Link} from "react-router";
import $ from "jquery";
import style from "./MsgDetailPage.css";
import ToolBar from "./ToolBar/ToolBar";
import LoadingLayer from "../LoadingLayer/LoadingLayer";

export default class MsgDetailPage extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            msgId: this.props.params.msgId,
            contentHeight: 0,
            isLoading: true,
            outerStyle: {height: 0},
        };
    }

    fetchDetail() {
        let msgId = this.state.msgId;
        $.ajax({
            type: 'GET',
            url: '/msg-detail',
            data: {'msgId': msgId},
            dataType: 'json',
            success: (response) => {
                this.setState({
                    msgTitle: response.data.title,
                    msgContent: response.data.content,
                    isLoading: false,   // 首屏加载完成, 标记loading结束
                });
                console.log(`msg-detail?msgId=${msgId} 请求成功, msgContent=${this.state.msgContent}`);
            },
            error: () => {
                console.log(`msg-detail?msgId=${msgId} 请求异常`);
            }
        });
    }

    componentDidMount() {
        // 调整loading界面的样式
        let ToolBar = $(this.refs.ToolBar.refs.ToolBarContainter);
        this.setState({outerStyle: {height: window.innerHeight - ToolBar.height()}});

        // 发起数据加载(setTimeout模拟延迟)
        setTimeout(() => {
            this.fetchDetail();
        }, 1000);
    }

    componentDidUpdate() {
        // 加载完成
        if (!this.state.isLoading) {
            let title = $(this.refs.MsgTitle);
            let container = $(this.refs.MsgContainer);
            let ToolBar = $(this.refs.ToolBar.refs.ToolBarContainter);

            // 上半部分总高度
            let height = title.height() + parseInt(title.css('padding-top')) +
                parseInt(title.css('padding-bottom')) +
                parseInt(container.css("padding-top")) +
                parseInt(container.css("padding-bottom")) +
                parseInt(ToolBar.height());

            // 窗口高度-上半部分总高度作为文章的最小高度
            if (this.state.contentHeight != window.innerHeight - height) { // 如果一样则不要setState避免递归渲染
                this.setState({
                    contentHeight: window.innerHeight - height,
                });
            }
        }
    }

    renderLoading() {
        let outerStyle = {
            height: window.innerHeight,
        };
        return (
            <div>
                <ToolBar ref="ToolBar"/>
                <LoadingLayer outerStyle={this.state.outerStyle}/>
            </div>
        );
    }

    renderPage() {
        // refs属性会捕获对应的原生的Dom节点，会在componentDidUpdate中访问Dom来动态计算高度
        return (
            <div>
                <ToolBar ref="ToolBar"/>
                <h1 id={style.MsgTitle} ref="MsgTitle">{this.state.msgTitle}</h1>
                <div id={style.MsgContainer} ref="MsgContainer" style={{minHeight: this.state.contentHeight}}>
                    <p id={style.MsgContent}>{this.state.msgContent}</p>
                </div>
            </div>
        );
    }

    render() {
        if (this.state.isLoading) {
            return this.renderLoading();
        } else {
            return this.renderPage();
        }
    }
}

MsgDetailPage.contextTypes = {
    router: () => { React.PropTypes.object.isRequired }
};
